@@ -97,6 +97,7 @@ var (
 	Ether_8023_Frame    = &decode.Group{Name: "ether8023_frame"}
 	Exif                = &decode.Group{Name: "exif"}
 	Fairplay_SPC        = &decode.Group{Name: "fairplay_spc"}
+	FIT                 = &decode.Group{Name: "fit"}
 	FLAC                = &decode.Group{Name: "flac"}
 	FLAC_Frame          = &decode.Group{Name: "flac_frame"}
 	FLAC_Metadatablock  = &decode.Group{Name: "flac_metadatablock"}
@@ -125,6 +126,9 @@ var (
 	JPEG                = &decode.Group{Name: "jpeg"}
 	JSON                = &decode.Group{Name: "json"}
 	JSONL               = &decode.Group{Name: "jsonl"}
+	LevelDB_Descriptor  = &decode.Group{Name: "leveldb_descriptor"}
+	LevelDB_LDB         = &decode.Group{Name: "leveldb_table"}
+	LevelDB_LOG         = &decode.Group{Name: "leveldb_log"}
 	LuaJIT              = &decode.Group{Name: "luajit"}
 	MachO               = &decode.Group{Name: "macho"}
 	MachO_Fat           = &decode.Group{Name: "macho_fat"}
