@@ -247,7 +247,6 @@ func decodeSampleFlags(d *decode.D) {
 }
 
 func decodeBoxWithParentData(ctx *decodeContext, d *decode.D, parentData any, extraTypeMappers ...scalar.StrMapper) {
-	var typ string
 	var dataSize uint64
 	typeMappers := []scalar.StrMapper{boxDescriptions}
 	if len(extraTypeMappers) > 0 {
@@ -255,7 +254,7 @@ func decodeBoxWithParentData(ctx *decodeContext, d *decode.D, parentData any, ex
 	}
 
 	boxSize := d.FieldU32("size", boxSizeNames)
-	typ = d.FieldStr("type", 4, charmap.ISO8859_1, typeMappers...)
+	typ := d.FieldStr("type", 4, charmap.ISO8859_1, typeMappers...)
 
 	switch boxSize {
 	case boxSizeRestOfFile:
@@ -313,7 +312,7 @@ type irefBox struct {
 }
 
 type trakBox struct {
-	trackID int
+	track *track
 }
 
 type moofBox struct {
@@ -321,7 +320,7 @@ type moofBox struct {
 }
 
 type trafBox struct {
-	trackID        int
+	track          *track
 	baseDataOffset int64
 	moof           *moof
 }
@@ -422,7 +421,11 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldU32("current_time")
 		d.FieldU32("next_track_id")
 	case "trak":
-		decodeBoxesWithParentData(ctx, d, &trakBox{})
+		t := &track{}
+		ctx.tracks = append(ctx.tracks, t)
+		decodeBoxesWithParentData(ctx, d, &trakBox{
+			track: t,
+		})
 	case "edts":
 		decodeBoxes(ctx, d)
 	case "elst":
@@ -482,8 +485,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldFP32("track_height")
 
 		if t := ctx.currentTrakBox(); t != nil {
-			t.trackID = trackID
-			_ = ctx.currentTrack()
+			t.track.id = trackID
 		}
 	case "mdia":
 		decodeBoxes(ctx, d)
@@ -555,15 +557,27 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldU24("flags")
 		entryCount := d.FieldU32("entry_count")
 		var i uint64
+		var drefURL string
 		d.FieldStructArrayLoop("boxes", "box", func() bool { return i < entryCount }, func(d *decode.D) {
 			size := d.FieldU32("size")
-			d.FieldUTF8("type", 4)
+			typ := d.FieldUTF8("type", 4)
 			d.FieldU8("version")
 			d.FieldU24("flags")
 			dataSize := size - 12
-			d.FieldRawLen("data", int64(dataSize*8))
+			switch typ {
+			case "url ":
+				drefURL = d.FieldUTF8("data", int(dataSize))
+			default:
+				d.FieldRawLen("data", int64(dataSize*8))
+			}
 			i++
 		})
+
+		if t := ctx.currentTrack(); t != nil {
+			t.dref = true
+			t.drefURL = drefURL
+		}
+
 	case "stbl":
 		decodeBoxes(ctx, d)
 	case "stsd":
@@ -878,10 +892,10 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		var i uint64
 		d.FieldStructArrayLoop("entries", "entry", func() bool { return i < entryCount }, func(d *decode.D) {
 			d.FieldS32("sample_count")
+			// ISO/IEC14496-12 says version 0 is unsigned and version 1 is signed
+			// in preactice it seems muxers write it as signed for both version
 			switch version {
-			case 0:
-				d.FieldU32("sample_offset")
-			case 1:
+			case 0, 1:
 				d.FieldS32("sample_offset")
 			}
 			i++
@@ -964,16 +978,17 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 	case "moof":
 		offset := (d.Pos() / 8) - 8
 		decodeBoxesWithParentData(ctx, d, &moofBox{offset: offset})
-		// Track Fragment
-	case "traf":
-		decodeBoxesWithParentData(ctx, d, &trafBox{})
-		// Movie Fragment Header
-	case "mfhd":
+	case "traf": // Track Fragment
+		t := &track{fragment: true}
+		ctx.tracks = append(ctx.tracks, t)
+		decodeBoxesWithParentData(ctx, d, &trafBox{
+			track: t,
+		})
+	case "mfhd": // Movie Fragment Header
 		d.FieldU8("version")
 		d.FieldU24("flags")
 		d.FieldU32("sequence_number")
-		// Track Fragment Header
-	case "tfhd":
+	case "tfhd": // Track Fragment Header
 		d.FieldU8("version")
 		baseDataOffsetPresent := false
 		sampleDescriptionIndexPresent := false
@@ -1016,15 +1031,14 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		}
 
 		if t := ctx.currentTrafBox(); t != nil {
-			t.trackID = trackID
+			t.track.id = trackID
 			t.moof = m
 			t.baseDataOffset = baseDataOffset
 		}
 		if t := ctx.currentTrack(); t != nil {
 			t.moofs = append(t.moofs, m)
 		}
-		// Track Fragment Run
-	case "trun":
+	case "trun": // Track Fragment Run
 		m := &moof{}
 		if t := ctx.currentTrafBox(); t != nil {
 			m = t.moof
@@ -1140,9 +1154,9 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldU8("version")
 		d.FieldU24("flags")
 		d.FieldU32("mfra_size")
+
+	case "iloc": // HEIC image
 		// TODO: item location
-		// HEIC image
-	case "iloc":
 		version := d.FieldU8("version")
 		d.FieldU24("flags")
 
@@ -1770,6 +1784,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		default:
 			d.FieldRawLen("message_data", d.BitsLeft())
 		}
+
 	default:
 		// there are at least 4 ways to encode udta metadata in mov/mp4 files.
 		//
