@@ -134,6 +134,7 @@ type stsz struct {
 
 type track struct {
 	seenHdlr           bool
+	fragment           bool
 	id                 int
 	sampleDescriptions []sampleDescription
 	subType            string
@@ -144,6 +145,8 @@ type track struct {
 	objectType         int // if data format is "mp4a"
 	defaultIVSize      int
 	moofs              []*moof // for fmp4
+	dref               bool
+	drefURL            string
 }
 
 type pathEntry struct {
@@ -154,16 +157,7 @@ type pathEntry struct {
 type decodeContext struct {
 	opts   format.MP4_In
 	path   []pathEntry
-	tracks map[int]*track
-}
-
-func (ctx *decodeContext) lookupTrack(id int) *track {
-	t, ok := ctx.tracks[id]
-	if !ok {
-		t = &track{id: id}
-		ctx.tracks[id] = t
-	}
-	return t
+	tracks []*track
 }
 
 func (ctx *decodeContext) isParent(typ string) bool {
@@ -211,24 +205,49 @@ func (ctx *decodeContext) currentMetaBox() *metaBox {
 
 func (ctx *decodeContext) currentTrack() *track {
 	if t := ctx.currentTrakBox(); t != nil {
-		return ctx.lookupTrack(t.trackID)
+		return t.track
 	}
 	if t := ctx.currentTrafBox(); t != nil {
-		return ctx.lookupTrack(t.trackID)
+		return t.track
 	}
 	return nil
 }
 
 func mp4Tracks(d *decode.D, ctx *decodeContext) {
-	// keep track order stable
-	var sortedTracks []*track
-	for _, t := range ctx.tracks {
-		sortedTracks = append(sortedTracks, t)
+	type trackCollected struct {
+		track  *track
+		order  int
+		moofss [][]*moof
 	}
-	slices.SortFunc(sortedTracks, func(a, b *track) int { return cmpex.Compare(a.id, b.id) })
+
+	var tracksCollected []*trackCollected
+	tracksCollectedSeen := map[int]*trackCollected{}
+	for i, t := range ctx.tracks {
+		tc, ok := tracksCollectedSeen[t.id]
+		if !ok {
+			tc = &trackCollected{
+				order: i,
+				track: t,
+			}
+			tracksCollectedSeen[t.id] = tc
+			tracksCollected = append(tracksCollected, tc)
+		}
+
+		// TODO: error if not fragmented and seen before?
+
+		tc.moofss = append(tc.moofss, t.moofs)
+	}
+
+	// sort by id then order in file
+	slices.SortStableFunc(tracksCollected, func(a, b *trackCollected) int {
+		if r := cmpex.Compare(a.track.id, b.track.id); r != 0 {
+			return r
+		}
+		return cmpex.Compare(a.order, b.order)
+	})
 
 	d.FieldArray("tracks", func(d *decode.D) {
-		for _, t := range sortedTracks {
+		for _, tc := range tracksCollected {
 			decodeSampleRange := func(d *decode.D, t *track, decodeSample bool, dataFormat string, name string, firstBit int64, nBits int64, inArg any) {
 				d.RangeFn(firstBit, nBits, func(d *decode.D) {
 					if !decodeSample {
@@ -277,6 +296,8 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 			}
 
 			d.FieldStruct("track", func(d *decode.D) {
+				t := tc.track
+
 				d.FieldValueUint("id", uint64(t.id))
 
 				trackSDDataFormat := "unknown"
@@ -287,9 +308,13 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 						trackSDDataFormat = sd.originalFormat
 					}
 				}
-
 				d.FieldValueStr("data_format", trackSDDataFormat, dataFormatNames)
 
+				if t.dref && t.drefURL != "" {
+					d.FieldValueStr("data_reference_url", t.drefURL)
+					return
+				}
+
 				switch trackSDDataFormat {
 				case "lpcm",
 					"raw ",
@@ -361,8 +386,6 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 								}
 							}
 
-							// log.Println(logStrFn())
-
 							decodeSampleRange(d, t, ctx.opts.DecodeSamples, trackSDDataFormat, "sample", sampleOffset*8, stszEntry.size*8, t.formatInArg)
 
 							sampleOffset += stszEntry.size
@@ -373,48 +396,50 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 					}
 
 					sampleNr := 0
-					for _, m := range t.moofs {
-						for trunNr, trun := range m.truns {
-							var senc senc
-							if trunNr < len(m.sencs) {
-								senc = m.sencs[trunNr]
-							}
-							sampleOffset := m.offset + trun.dataOffset
 
-							for trunSampleNr, sz := range trun.samplesSizes {
-								dataFormat := trackSDDataFormat
-								if m.defaultSampleDescriptionIndex != 0 && m.defaultSampleDescriptionIndex-1 < len(t.sampleDescriptions) {
-									sd := t.sampleDescriptions[m.defaultSampleDescriptionIndex-1]
-									dataFormat = sd.dataFormat
-									if sd.originalFormat != "" {
-										dataFormat = sd.originalFormat
+					for _, ms := range tc.moofss {
+						for _, m := range ms {
+							for trunNr, trun := range m.truns {
+								var senc senc
+								if trunNr < len(m.sencs) {
+									senc = m.sencs[trunNr]
+								}
+								sampleOffset := m.offset + trun.dataOffset
+
+								for trunSampleNr, sz := range trun.samplesSizes {
+									dataFormat := trackSDDataFormat
+									if m.defaultSampleDescriptionIndex != 0 && m.defaultSampleDescriptionIndex-1 < len(t.sampleDescriptions) {
+										sd := t.sampleDescriptions[m.defaultSampleDescriptionIndex-1]
+										dataFormat = sd.dataFormat
+										if sd.originalFormat != "" {
+											dataFormat = sd.originalFormat
+										}
 									}
+
+									// logStrFn := func() string {
+									// 	return fmt.Sprintf("%d: %s: %d: (%s): sz=%d %d+%d=%d",
+									// 		t.id,
+									// 		dataFormat,
+									// 		sampleNr,
+									// 		trackSDDataFormat,
+									// 		sz,
+									// 		m.offset,
+									// 		m.dataOffset,
+									// 		sampleOffset,
+									// 	)
+									// }
+
+									decodeSample := ctx.opts.DecodeSamples
+									if trunSampleNr < len(senc.entries) {
+										// TODO: encrypted
+										decodeSample = false
+									}
+
+									decodeSampleRange(d, t, decodeSample, dataFormat, "sample", sampleOffset*8, sz*8, t.formatInArg)
+
+									sampleOffset += sz
+									sampleNr++
 								}
-
-								// logStrFn := func() string {
-								// 	return fmt.Sprintf("%d: %s: %d: (%s): sz=%d %d+%d=%d",
-								// 		t.id,
-								// 		dataFormat,
-								// 		sampleNr,
-								// 		trackSDDataFormat,
-								// 		sz,
-								// 		m.offset,
-								// 		m.dataOffset,
-								// 		sampleOffset,
-								// 	)
-								// }
-								// log.Println(logStrFn())
-
-								decodeSample := ctx.opts.DecodeSamples
-								if trunSampleNr < len(senc.entries) {
-									// TODO: encrypted
-									decodeSample = false
-								}
-
-								decodeSampleRange(d, t, decodeSample, dataFormat, "sample", sampleOffset*8, sz*8, t.formatInArg)
-
-								sampleOffset += sz
-								sampleNr++
 							}
 						}
 					}
@@ -431,7 +456,7 @@ func mp4Decode(d *decode.D) any {
 	ctx := &decodeContext{
 		opts:   mi,
 		path:   []pathEntry{{typ: "root"}},
-		tracks: map[int]*track{},
+		tracks: []*track{},
 	}
 
 	// TODO: nicer, validate functions without field?
